Cave Story (Controls)

- Controls -
（Can be adjusted with DoConfig.exe)
* Action

Move left and right | Left-arrow and right-arrow
Look up | Up-arrow
Search (or look down in midair) | Down-arrow
Jump | Z
Fire weapon | X
Change weapon | A (back) and S (forward)
Item Screen | Q
Display map (requires item) | W

* Conversation

Yes/No selection | Left-arrow and Right-arrow
Continue conversation | X or Z

* Item Screen

Selection | Arrow keys
Examine / Use | Z
Leave Screen | X

* You can quit or reset the game by pressing Esc.